@@ -377,6 +377,19 @@ def copy_singlefile_from_archive(scrfile_path, dstfile_path):
     shutil.copy(str(scrfile_path), str(dstfile_path))
 #################################################################################################
 #################################################################################################
+def mosaic_tifs(tile_filepaths, mosaic_filepath):
+    if mosaic_filepath.is_file():
+        mosaic_filepath.unlink()
+    args = ["gdal_merge.py",
+            "-co", "TILED=YES",
+            "-co", "COMPRESS=DEFLATE",
+            "-n", "0",
+            "-a_nodata", "0",
+            "-o", str(mosaic_filepath),
+            "-pct"] + [str(fp) for fp in tile_filepaths]
+
+    cmd_output = subprocess.run(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    log.debug(f"exit code {cmd_output.returncode} --> {args}")
 
 def read_raster_info(raster_filepath):
     ds = gdal.Open(str(raster_filepath))
@@ -621,7 +634,7 @@ def get_sitecode_from_aoiwkt_parse(aoi_wkt, t_srs):
 
        aoi_geom = get_aoi_geometry(aoi_wkt, int(aoi_epsg))
        if aoi_geom["status"] == "ERROR":
-          logger.error(aoi_geom["message"])
+          log.error(aoi_geom["message"])
        else:
           aoi_geom = aoi_geom["output"]
 
